=======
Credits
=======

Development Lead
----------------

* Federico Bianchi <f.bianchi@unibocconi.it>
* Debora Nozza <debora.nozza@unibocconi.it>

Contributors
------------

None yet. Why not be the first?
